#ifndef _VERTEX_KEYWORD_TOKENS_H
#define _VERTEX_KEYWORD_TOKENS_H

enum VertexKeywordTokens {
/* zzEOF_TOKEN=1, */
V_EOF=1,
V_DECIMAL_NUMBER,
V_FLOAT1,
V_FLOAT2,
V_DBASE,
V_BBASE,
V_OBASE,
V_HBASE,
V_STRING,
V_EQ,
V_DOT,
V_PLUS,
V_MINUS,
V_BANG,
V_TILDE,
V_AND,
V_NAND,
V_OR,
V_NOR,
V_XOR,
V_XNOR,
V_STAR,
V_SLASH,
V_MOD,
V_EQ2,
V_NEQ,
V_EQ3,
V_NEQ2,
V_AND2,
V_AND3,
V_OR2,
V_LT,
V_LEQ,
V_GT,
V_GEQ,
V_XNOR2,
V_SHL,
V_SHR,
V_QUEST,
V_COLON,
V_LP,
V_RP,
V_LBRACK,
V_RBRACK,
V_LBRACE,
V_RBRACE,
V_COMMA,
V_AT,
V_SEMI,
V_POUND,
V_RARROW,
V_SPD1,
V_SPD2,
V_IDENTIFIER,
V_IDENTIFIER2,
V_IDENDOT,
V_LEVEL_SYMBOL_EXTRA,
V_HYPHEN,
V_EDGE_SYMBOL,
V_FUNCTION_NAME,
V_OUTPUT_SYMBOL,
V_ALWAYS,
V_ANDLIT,
V_ASSIGN,
V_BEGIN,
V_BUF,
V_BUFIF0,
V_BUFIF1,
V_CASE,
V_CASEX,
V_CASEZ,
V_CMOS,
V_DEASSIGN,
V_DEFAULT,
V_DEFPARAM,
V_DISABLE,
V_EDGE,
V_ELSE,
V_END,
V_ENDCASE,
V_ENDFUNCTION,
V_ENDMODULE,
V_ENDPRIMITIVE,
V_ENDSPECIFY,
V_ENDTABLE,
V_ENDTASK,
V_EVENT,
V_FOR,
V_FORCE,
V_FOREVER,
V_FORK,
V_FUNCTION,
V_HIGHZ0,
V_HIGHZ1,
V_IF,
V_INITIAL,
V_INOUT,
V_INPUT,
V_INTEGER,
V_JOIN,
V_LARGE,
V_MACROMODULE,
V_MEDIUM,
V_MODULE,
V_NANDLIT,
V_NEGEDGE,
V_NMOS,
V_NORLIT,
V_NOTIF0,
V_NOTIF1,
V_NOTLIT,
V_ORLIT,
V_OUTPUT,
V_PARAMETER,
V_PMOS,
V_POSEDGE,
V_PRIMITIVE,
V_PULL0,
V_PULL1,
V_PULLDOWN,
V_PULLUP,
V_RCMOS,
V_REAL,
V_REG,
V_RELEASE,
V_REPEAT,
V_RNMOS,
V_RPMOS,
V_RTRAN,
V_RTRANIF0,
V_RTRANIF1,
V_SCALARED,
V_SMALL,
V_SPECIFY,
V_SPECPARAM,
V_STRONG0,
V_STRONG1,
V_SUPPLY0,
V_SUPPLY1,
V_TABLE,
V_TASK,
V_TIME,
V_TRAN,
V_TRANIF0,
V_TRANIF1,
V_TRI,
V_TRI0,
V_TRI1,
V_TRIAND,
V_TRIOR,
V_TRIREG,
V_VECTORED,
V_WAIT,
V_WAND,
V_WEAK0,
V_WEAK1,
V_WHILE,
V_WIRE,
V_WOR,
V_XNORLIT,
V_XORLIT
};
#endif

/*
 * $Id: keyword_tokens.h,v 1.2 2009/12/29 07:18:01 gtkwave Exp $
 * $Log: keyword_tokens.h,v $
 * Revision 1.2  2009/12/29 07:18:01  gtkwave
 * header fix for macro vs enum conflict
 *
 * Revision 1.1.1.1  2007/05/30 04:25:42  gtkwave
 * Imported sources
 *
 * Revision 1.1  2007/04/21 21:08:51  gtkwave
 * changed from vertex to vermin
 *
 * Revision 1.2  2007/04/20 02:08:11  gtkwave
 * initial release
 *
 */

